
--localization
local _, L = ...

--define local vars and defaults
local UpdateElapsed = 0
local UpdateInterval = 0.25
local Alarm = nil

local function SetDefaults() --saved settings
	KCrazyArrowHide_Settings = {
		["Version"] = tonumber(GetAddOnMetadata("KCrazyArrowHide", "Version")),
		["Enabled"] = true,
		["Sleep"] = 4,
		["HideMounted"] = false
	}
end
SetDefaults()

local function print(Msg)
	if Msg == nil then Msg = ""; end
	DEFAULT_CHAT_FRAME:AddMessage(L["CAH"]..": " .. tostring(Msg))
end

function KCrazyArrowHideFrame_OnEvent(self, event, ...)
	if event == "ADDON_LOADED" and select(1,...) == "KCrazyArrowHide" then
		--vars loaded from saved settings
		--check ver of settings and upgrade if needed
		if KCrazyArrowHide_Settings.Version == nil then KCrazyArrowHide_Settings.Version = 0; end	--in case the setting did not exist
		if KCrazyArrowHide_Settings.Version < tonumber(GetAddOnMetadata("KCrazyArrowHide", "Version")) then
			--upgrade older version settings
			local OldVerOptions = KCrazyArrowHide_Settings	 --save loaded settings
			SetDefaults()	 --load default settings again
			for k,v in pairs(OldVerOptions) do
				if OldVerOptions[k] ~= nil then
					KCrazyArrowHide_Settings[k] = OldVerOptions[k]
				end
			end
			KCrazyArrowHide_Settings.Version = tonumber(GetAddOnMetadata("KCrazyArrowHide", "Version"))	--reset correct version number
		end
	end
	if TomTom and KCrazyArrowHide_Settings.Enabled then
		if (event == "PLAYER_REGEN_DISABLED") then
			Alarm = nil
			TomTomCrazyArrow:Hide()
		elseif (event == "PLAYER_REGEN_ENABLED") then
			if not (KCrazyArrowHide_Settings.HideMounted and IsMounted()) then
				Alarm = GetTime() + KCrazyArrowHide_Settings.Sleep
			end
		end
	end
end

function KCrazyArrowHideFrame_OnUpdate(Self, Elapsed, ...)
	UpdateElapsed = UpdateElapsed + Elapsed
	if UpdateElapsed >= UpdateInterval then
		if Alarm and TomTom and KCrazyArrowHide_Settings.Enabled then
			if Alarm then
				if GetTime() > Alarm then
					TomTomCrazyArrow:Show()
					Alarm = nil
				end
			end
		end
		if not InCombatLockdown() then
			if (KCrazyArrowHide_Settings.HideMounted and IsMounted() and TomTomCrazyArrow:IsVisible()) then
				Alarm = nil
				TomTomCrazyArrow:Hide()
			elseif (KCrazyArrowHide_Settings.HideMounted and not IsMounted() and not TomTomCrazyArrow:IsVisible() and Alarm == nil) then
				Alarm = GetTime() + KCrazyArrowHide_Settings.Sleep
			end
		end
		UpdateElapsed = 0
	end
end

function KCrazyArrowHide_Command(Msg, Editbox)
	print("r17 (translators are needed)")
	if Msg then Msg=strlower(Msg); end
	if Msg == "" or Msg == L["help"] or Msg == "?" then
		print(L["Use /KCAH | /"]..L["CAH"].." ["..L["on"].."/"..L["off"].."/"..L["mnton"].."/"..L["mntoff"].."/"..L["show"].."/"..L["hide"].."/#/"..L["defaults"].."/"..L["help"].."].")
		if Msg == "" then
			if KCrazyArrowHide_Settings.Enabled then
				print(format(L["%s is currently enabled."], "Crazy Arrow Hide"))
			else
				print(format(L["%s is currently disabled."], "Crazy Arrow Hide"))
			end
			print(format("Sleep value is %s.", KCrazyArrowHide_Settings.Sleep))
			if KCrazyArrowHide_Settings.HideMounted == true then
				print(L["Hide when mounted is currently enabled."])
			else
				print(L["Hide when mounted is currently disabled."])
			end
		elseif Msg == L["help"] or Msg == "?" then
			print(format("%s/%s to enable or disable automatic hiding.", L["On"], L["off"]))
			print(format("%s/%s to manually show or hide the Crazy Arrow.", L["Show"], L["hide"]))
			print(format("%s/%s to enable or disable arrow hiding when mounted.", L["Mnton"], L["mntoff"]))
			print("# (a number in seconds) to set the delay out of combat to show the Crazy Arrow.")
			print(format("%s to reset settings.", L["Default"]))
			print(format("Example: /%s %s", L["CAH"], L["on"]))
		end
	elseif tonumber(Msg) ~= nil then
		KCrazyArrowHide_Settings.Sleep = tonumber(Msg)
		print(format("Sleep set to %s.", tostring(KCrazyArrowHide_Settings.Sleep)))
	elseif Msg == L["on"] or Msg == L["enable"] then
		KCrazyArrowHide_Settings.Enabled = true
		print(format("%s is now on.", "Crazy Arrow Hide"))
	elseif Msg == "off" or Msg == "disable" then
		if TomTom and not TomTomCrazyArrow:IsVisible() then TomTomCrazyArrow:Show(); end
		KCrazyArrowHide_Settings.Enabled = false
		print(format("%s is now off.", "Crazy Arrow Hide"))
	elseif Msg == L["show"] and TomTom then
		TomTomCrazyArrow:Show()
		print(L["Show the Crazy Arrow."])
	elseif Msg == L["hide"] and TomTom then
		TomTomCrazyArrow:Hide()
		print(L["Hide the Crazy Arrow."])
	elseif Msg == L["mnton"] then
		KCrazyArrowHide_Settings.HideMounted = true
		print(L["Hide when mounted enabled."])
	elseif Msg == L["mntoff"] then
		KCrazyArrowHide_Settings.HideMounted = false
		if not InCombatLockdown() and not TomTomCrazyArrow:IsVisible() then TomTomCrazyArrow:Show(); end
		print(L["Hide when mounted disabled."])
	elseif Msg == L["default"] or Msg == L["defaults"] or Msg == L["reset"] then
		SetDefaults()
		if not InCombatLockdown() and not TomTomCrazyArrow:IsVisible() then TomTomCrazyArrow:Show(); end
		print(L["Defaults restored."])
	end
	if not TomTom then
		print(L["NOTICE: Required addon TomTom is not loaded."])
	end
end

--Create an anonymous blank frame
local KCrazyArrowHideFrame = CreateFrame("Frame")
KCrazyArrowHideFrame:RegisterEvent("ADDON_LOADED")
KCrazyArrowHideFrame:RegisterEvent("PLAYER_REGEN_ENABLED")
KCrazyArrowHideFrame:RegisterEvent("PLAYER_REGEN_DISABLED")
KCrazyArrowHideFrame:SetScript("OnEvent", KCrazyArrowHideFrame_OnEvent)
KCrazyArrowHideFrame:SetScript("OnUpdate", KCrazyArrowHideFrame_OnUpdate)

--setup slash command feature
SlashCmdList["KCrazyArrowHide"]=KCrazyArrowHide_Command
SLASH_KCrazyArrowHide1, SLASH_KCrazyArrowHide2="/KCAH", "/"..L["CAH"]
print("Crazy Arrow Hide".." r17 (translators are needed)")
